textgrad.model
==============

.. automodule:: textgrad.model

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      BlackboxLLM
      Module
      SearchEngine
   
   

   
   
   



